@@ -12,16 +12,6 @@
 #define QT_COMPILER_SUPPORTS_SSE4_1 1
 #define QT_COMPILER_SUPPORTS_SSE4_2 1
 #define QT_COMPILER_SUPPORTS_AVX 1
-#define QT_COMPILER_SUPPORTS_AVX2 1
-#define QT_COMPILER_SUPPORTS_AVX512F 1
-#define QT_COMPILER_SUPPORTS_AVX512BW 1
-#define QT_COMPILER_SUPPORTS_AVX512CD 1
-#define QT_COMPILER_SUPPORTS_AVX512DQ 1
-#define QT_COMPILER_SUPPORTS_AVX512ER 1
-#define QT_COMPILER_SUPPORTS_AVX512IFMA 1
-#define QT_COMPILER_SUPPORTS_AVX512PF 1
-#define QT_COMPILER_SUPPORTS_AVX512VBMI 1
-#define QT_COMPILER_SUPPORTS_AVX512VL 1
 #define QT_FEATURE_debug_and_release -1
 #define QT_FEATURE_build_all -1
 #define QT_FEATURE_c__11 1
